require 'spec_helper'
require 'telltale/data'

RSpec.describe Telltale::Data do
  Rails = Class.new do
    def self.application; end
    def self.env; end
  end

  let(:started) { Time.at 1 }
  let(:finished) { Time.at 10 }
  let(:payload) { { controller: 'contacts', action: 'show', status: 200 } }
  let(:data) { Telltale::Data.new started, finished, payload }

  before do
    allow(Rails).to receive_message_chain(:application, :class, :parent_name).and_return('MyApp')
    allow(Rails).to receive(:env).and_return('staging')
  end

  describe '.compile' do
    it 'compiles the data for the total request time metric' do
      expect(described_class.compile(started, finished, payload)).to match_array [Hash, Hash]
    end
  end

  describe '#all' do
    it 'compiles the data all metrics' do
      expect(data.all).to match_array [Hash, Hash]
    end
  end

  describe '#total_time' do
    it 'compiles the data for the total request time metric' do
      expect(data.total_time).to eq(
        metric: 'telltale.rails.total_time',
        value: 9000,
        timestamp: Time.now.to_i,
        tags: {
          http_status: 200,
          controller: 'contacts',
          action: 'contacts.show',
          host: 'odin',
          environment: 'staging',
          app: 'myapp',
        },
      )
    end
  end

  describe '#request_count' do
    it 'compiles the data for the request count metric' do
      expect(data.request_count).to eq(
        metric: 'telltale.rails.request_count',
        value: 1,
        timestamp: Time.now.to_i,
        tags: {
          http_status: 200,
          controller: 'contacts',
          action: 'contacts.show',
          host: 'odin',
          environment: 'staging',
          app: 'myapp',
        },
      )
    end
  end
end
